==> ksystemlog-20.08.0.tar.xz: ksystemlog-20.08.0/src/modes/open/openFactory.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef LOG_MODE_OPEN_FACTORY_H
#define LOG_MODE_OPEN_FACTORY_H

#include "logModeFactory.h"
#include "logModeConfiguration.h"

class OpenLogModeFactory : public LogModeFactory
{
    Q_OBJECT

public:
    explicit OpenLogModeFactory(QWidget *parent);

    ~OpenLogModeFactory();

    QList<LogMode *> createLogModes() const override;

    LogModeAction *createLogModeAction() const override;

private:
    QWidget *parent;
};

#endif // _LOG_MODE_OPEN_FACTORY_H

==> ksystemlog-21.03.80.tar.xz: ksystemlog-21.03.80/src/modes/open/openFactory.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef LOG_MODE_OPEN_FACTORY_H
#define LOG_MODE_OPEN_FACTORY_H

#include "logModeConfiguration.h"
#include "logModeFactory.h"

class OpenLogModeFactory : public LogModeFactory
{
    Q_OBJECT

public:
    explicit OpenLogModeFactory(QWidget *parent);

    ~OpenLogModeFactory() override;

    QList<LogMode *> createLogModes() const override;

    LogModeAction *createLogModeAction() const override;

private:
    QWidget *const mParent;
};

#endif // _LOG_MODE_OPEN_FACTORY_H
